@@ -22,12 +22,12 @@
 #include <lsr/ls_confparser.h>
 #include <modsecurity/modsecurity.h>
 #include <modsecurity/transaction.h>
-#include <modsecurity/rules.h>
+#include <modsecurity/rules_set.h>
 class session;
 
 #define MNAME                       mod_security
 #define ModuleNameStr               "Mod_Security"
-#define VERSIONNUMBER               "1.2"
+#define VERSIONNUMBER               "1.3"
 
 #define MODULE_VERSION_INFO         ModuleNameStr " " VERSIONNUMBER
 
@@ -72,7 +72,7 @@ void ls_modSecLogCb(void *_session, const void *data)
         return ;
 
     lsi_session_t *session = (lsi_session_t *)_session;
-    g_api->log(session, LSI_LOG_DEBUG, "[Module:%s] %s\n", ModuleNameStr,
+    g_api->log(session, LSI_LOG_INFO, "[Module:%s] %s\n", ModuleNameStr,
                (const char *)data);
 }
 
@@ -97,7 +97,7 @@ static int setSecRule(msc_conf_t *pConfig, char *value, int type, char *uri)
     int ret = 0;
     const char *error = NULL;
 
-    g_api->log(NULL, LSI_LOG_DEBUG,  "[Module:%s] setSecRule "
+    g_api->log(NULL, LSI_LOG_INFO,  "[Module:%s] setSecRule "
                "value: %s, type: %d %s\n",ModuleNameStr, value, type,
                type == 3 ? uri : "");
 
@@ -131,7 +131,7 @@ static void *ParseConfig(module_param_info_t *param, int param_count,
     msc_conf_t  *pInitConfig = (msc_conf_t *)_initial_config;
     msc_conf_t *pConfig = new msc_conf_t;
 
-    g_api->log(NULL, LSI_LOG_DEBUG,  "[Module:%s] ParseConfig entry, "
+    g_api->log(NULL, LSI_LOG_INFO,  "[Module:%s] ParseConfig entry, "
                 "level %d, Mod_Security v%s.%s.%s\n", ModuleNameStr, level,
                 MODSECURITY_MAJOR, MODSECURITY_MINOR, MODSECURITY_PATCHLEVEL);
     if (!pConfig)
@@ -229,7 +229,7 @@ static void *ParseConfig(module_param_info_t *param, int param_count,
             else {
                 pConfig->enable = (strcasecmp(param[i].val, "on") == 0);
                 {
-                    g_api->log(NULL, LSI_LOG_DEBUG,  "[Module:%s] Enable flag "
+                    g_api->log(NULL, LSI_LOG_INFO,  "[Module:%s] Enable flag "
                                "interpreted as %d\n", ModuleNameStr,
                                pConfig->enable);
                 }
@@ -297,12 +297,12 @@ static int process_intervention (Transaction *t, lsi_param_t *rec)
                    "No log message specified\n",
                    ModuleNameStr);
     }
-    g_api->log(rec->session, LSI_LOG_DEBUG, "[Module:%s]"
+    g_api->log(rec->session, LSI_LOG_INFO, "[Module:%s]"
                "Intervention status code triggered: %d\n",
                ModuleNameStr, intervention.status);
     if (!intervention.url) {
         // NOT always logged in callback
-        g_api->log(rec->session, LSI_LOG_DEBUG, "[Module:%s]"
+        g_api->log(rec->session, LSI_LOG_INFO, "[Module:%s]"
                    "Log Message: %s\n",
                    ModuleNameStr, intervention.log);
     }
